@@ -49,7 +49,7 @@ class HistoryResponse:
             body=body,
         )
 
-    def __packed__(self) -> Dict[str, Any]:
+    def to_dict(self) -> Dict[str, Any]:
         headers = [[key, val] for key, val in self._headers.items()]
         return {
             "status": self._status,
@@ -58,6 +58,9 @@ class HistoryResponse:
             "body": self._body,
         }
 
+    def __packed__(self) -> Dict[str, Any]:
+        return self.to_dict()
+
     @classmethod
     def __unpacked__(cls, *,
                      status: int,
